from .client import (
    Client as Client,
    Proof as Proof,
    VerificationResult as VerificationResult,
)
from .config import Config as Config
from .exceptions import (
    SDKError as SDKError,
    ProofError as ProofError,
    VerificationError as VerificationError,
    AuthenticationError as AuthenticationError,
)

__version__ = "0.2.0"
